==> CGAL-5.4.1-doc_html.tar.xz: doc_html/Surface_mesh_simplification/group__PkgSurfaceMeshSimplificationRef.js <==
var group__PkgSurfaceMeshSimplificationRef =
[
    [ "Concepts", "group__PkgSurfaceMeshSimplificationConcepts.html", "group__PkgSurfaceMeshSimplificationConcepts" ],
    [ "Edge_collapse_visitor_base", "structCGAL_1_1Surface__mesh__simplification_1_1Edge__collapse__visitor__base.html", null ],
    [ "Bounded_normal_change_filter", "classCGAL_1_1Surface__mesh__simplification_1_1Bounded__normal__change__filter.html", [
      [ "Bounded_normal_change_filter", "classCGAL_1_1Surface__mesh__simplification_1_1Bounded__normal__change__filter.html#a0cfd8ea13c2265d9128194cfca208675", null ],
      [ "Bounded_normal_change_filter", "classCGAL_1_1Surface__mesh__simplification_1_1Bounded__normal__change__filter.html#afa984a31498ede63f04f9fe58f4a182c", null ],
      [ "operator()", "classCGAL_1_1Surface__mesh__simplification_1_1Bounded__normal__change__filter.html#a8b01495720d6ee1bdef96e4e85848c46", null ]
    ] ],
    [ "Bounded_normal_change_placement", "classCGAL_1_1Surface__mesh__simplification_1_1Bounded__normal__change__placement.html", [
      [ "Bounded_normal_change_placement", "classCGAL_1_1Surface__mesh__simplification_1_1Bounded__normal__change__placement.html#aa0930a43888d0bc99f51391b690c2b5e", null ],
      [ "Bounded_normal_change_placement", "classCGAL_1_1Surface__mesh__simplification_1_1Bounded__normal__change__placement.html#a3407420970b3b521a9f9fca035073c70", null ],
      [ "operator()", "classCGAL_1_1Surface__mesh__simplification_1_1Bounded__normal__change__placement.html#a5588d9ec9321610198e39d9f97af2b13", null ]
    ] ],
    [ "Constrained_placement", "classCGAL_1_1Surface__mesh__simplification_1_1Constrained__placement.html", [
      [ "Constrained_placement", "classCGAL_1_1Surface__mesh__simplification_1_1Constrained__placement.html#a4e6c8181c10222cc1534c4021c73afe1", null ]
    ] ],
    [ "Count_ratio_stop_predicate", "classCGAL_1_1Surface__mesh__simplification_1_1Count__ratio__stop__predicate.html", [
      [ "Count_ratio_stop_predicate", "classCGAL_1_1Surface__mesh__simplification_1_1Count__ratio__stop__predicate.html#ae7c4b33fe17aae30981353449882d73b", null ],
      [ "operator()", "classCGAL_1_1Surface__mesh__simplification_1_1Count__ratio__stop__predicate.html#a3c746ca87d0525ec54e83550b2370949", null ]
    ] ],
    [ "Count_stop_predicate", "classCGAL_1_1Surface__mesh__simplification_1_1Count__stop__predicate.html", [
      [ "Count_stop_predicate", "classCGAL_1_1Surface__mesh__simplification_1_1Count__stop__predicate.html#a3f6f8f8d3e19ed6429a4034b34f5a4d0", null ],
      [ "operator()", "classCGAL_1_1Surface__mesh__simplification_1_1Count__stop__predicate.html#ad4304de44e78302e78ab9c4b25252f33", null ]
    ] ],
    [ "Edge_length_cost", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__length__cost.html", [
      [ "Edge_length_cost", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__length__cost.html#a5dfab61ec6db0223d011c68fe70d2dad", null ],
      [ "operator()", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__length__cost.html#af5915cbbb2e9e1f15ae5f99daf4787c8", null ]
    ] ],
    [ "Edge_length_stop_predicate", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__length__stop__predicate.html", [
      [ "Edge_length_stop_predicate", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__length__stop__predicate.html#ada06f5ddd3b86d715a6820eebb09c02a", null ],
      [ "operator()", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__length__stop__predicate.html#a5e33c02017e71abb7a521863aaa10721", null ]
    ] ],
    [ "Edge_profile", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html", [
      [ "edge_descriptor", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#ac53009c4bdf3b085da3ab4df34c4fe84", null ],
      [ "edges_size_type", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#afc622e5fea3e9271a9e8f2a4dc36a678", null ],
      [ "FT", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#ad0c5db091a74548d651ac32abc2abcbc", null ],
      [ "Geom_traits", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#ad4194f46a47b26c789c9539875471718", null ],
      [ "halfedge_descriptor", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#aa8df05005d1c7ceba1bfb2c9e91991be", null ],
      [ "Point", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a1428e94a5c6d4906b6d24d987ddf2e19", null ],
      [ "Triangle_mesh", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a119f2e721d71532ab525ba919444f027", null ],
      [ "vertex_descriptor", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#ad192d90a05ef48861956fa8f2fa8fd6f", null ],
      [ "Vertex_point_map", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#ae3c96d83f9e89bc8630c416ed7c45376", null ],
      [ "border_edges", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a092d4e360d557f3dc4a43c9728131fa2", null ],
      [ "geom_traits", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a5bbab9c7967127dd0a1d254d7738eb56", null ],
      [ "left_face_exists", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a113070ed81cbade3ac0083973302436a", null ],
      [ "link", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a1aceb9a31fe08c91c72f14d7ca8981d7", null ],
      [ "p0", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#ab785a29f857e49df2c603754e6bfa927", null ],
      [ "p1", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#aeb9652afb34889604eb28f73c0f2d4d6", null ],
      [ "right_face_exists", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a30f659a5eaecdd3dd4593f95b7a39495", null ],
      [ "surface_mesh", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a7c10c291981cccf38adbad2503cd15f2", null ],
      [ "v0", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#ab5018d64678847a11b2a1ae3f060f20f", null ],
      [ "v0_v1", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a63fd769d1492330df0585a805e01291a", null ],
      [ "v0_vR", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a4dedf65f8be303336bb92ae0401b651f", null ],
      [ "v1", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a1d52cf119efcac309ee492642fe95851", null ],
      [ "v1_v0", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a8a157ccdc4e88eed183aa9aef4f64da4", null ],
      [ "v1_vL", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a9b4b3181813309ea6c3fe2f9969c4e38", null ],
      [ "vertex_point_map", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a4c9f88feb0185dee205637ebf4ffe457", null ],
      [ "vL", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a4faa5384a0c1ddff1b438a14b15779b5", null ],
      [ "vL_v0", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a647d2d477538ac0ebdc0271f1c64ff25", null ],
      [ "vR", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a510ab6920d65d2d0d806c62d4fe973ae", null ],
      [ "vR_v1", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a5d2e5f9251a7a1ebfb89a8aea83685bf", null ]
    ] ],
    [ "GarlandHeckbert_policies", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__policies.html", [
      [ "Get_cost", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__policies.html#a34846d79ca2a827ca86063a70bb94aac", null ],
      [ "Get_placement", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__policies.html#a4205f1bb9f683ecdb719ca7cf06e6a9c", null ],
      [ "GarlandHeckbert_policies", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__policies.html#abb4b9878f20244b515ed606e974237da", null ],
      [ "get_cost", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__policies.html#ad56b66ac448aec2f2a3ce0edad8f700b", null ],
      [ "get_placement", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__policies.html#abbac3f52bbc4b8b773ca0fbb6f184773", null ]
    ] ],
    [ "LindstromTurk_cost", "classCGAL_1_1Surface__mesh__simplification_1_1LindstromTurk__cost.html", [
      [ "LindstromTurk_cost", "classCGAL_1_1Surface__mesh__simplification_1_1LindstromTurk__cost.html#a7373afdc3960cdd92d26c56b961b9bb2", null ],
      [ "operator()", "classCGAL_1_1Surface__mesh__simplification_1_1LindstromTurk__cost.html#a4f1f44dd6e87334795826618e332e9bb", null ]
    ] ],
    [ "LindstromTurk_placement", "classCGAL_1_1Surface__mesh__simplification_1_1LindstromTurk__placement.html", [
      [ "LindstromTurk_placement", "classCGAL_1_1Surface__mesh__simplification_1_1LindstromTurk__placement.html#a2b44349a0543a6c94f211b50bbba2725", null ],
      [ "operator()", "classCGAL_1_1Surface__mesh__simplification_1_1LindstromTurk__placement.html#a4905c72cecc8ae67198f61b1bab26650", null ]
    ] ],
    [ "Midpoint_placement", "classCGAL_1_1Surface__mesh__simplification_1_1Midpoint__placement.html", [
      [ "Midpoint_placement", "classCGAL_1_1Surface__mesh__simplification_1_1Midpoint__placement.html#ae8420ca8ac91298c9e36cefa9781d6a2", null ],
      [ "operator()", "classCGAL_1_1Surface__mesh__simplification_1_1Midpoint__placement.html#a2d44e952ea69f039727b47ab3e7aa1c5", null ]
    ] ],
    [ "Polyhedral_envelope_filter", "classCGAL_1_1Surface__mesh__simplification_1_1Polyhedral__envelope__filter.html", [
      [ "FT", "classCGAL_1_1Surface__mesh__simplification_1_1Polyhedral__envelope__filter.html#a99e59acb6fab15420d04f9bf07121197", null ],
      [ "Polyhedral_envelope_filter", "classCGAL_1_1Surface__mesh__simplification_1_1Polyhedral__envelope__filter.html#a6b56416caa9952dd87388bd086ecee34", null ],
      [ "Polyhedral_envelope_filter", "classCGAL_1_1Surface__mesh__simplification_1_1Polyhedral__envelope__filter.html#a6d49a1bcbd2b263aef9f05dd40ddde8a", null ],
      [ "operator()", "classCGAL_1_1Surface__mesh__simplification_1_1Polyhedral__envelope__filter.html#a654e09685a569d356b7444ac356fd948", null ]
    ] ],
    [ "edge_collapse", "group__PkgSurfaceMeshSimplificationRef.html#ga89d399799260afa0c0ca2fd0edbcda74", null ]
];

==> CGAL-5.5.2-doc_html.tar.xz: doc_html/Surface_mesh_simplification/group__PkgSurfaceMeshSimplificationRef.js <==
var group__PkgSurfaceMeshSimplificationRef =
[
    [ "Concepts", "group__PkgSurfaceMeshSimplificationConcepts.html", "group__PkgSurfaceMeshSimplificationConcepts" ],
    [ "Edge_collapse_visitor_base", "structCGAL_1_1Surface__mesh__simplification_1_1Edge__collapse__visitor__base.html", null ],
    [ "Bounded_normal_change_filter", "classCGAL_1_1Surface__mesh__simplification_1_1Bounded__normal__change__filter.html", [
      [ "Bounded_normal_change_filter", "classCGAL_1_1Surface__mesh__simplification_1_1Bounded__normal__change__filter.html#a0cfd8ea13c2265d9128194cfca208675", null ],
      [ "Bounded_normal_change_filter", "classCGAL_1_1Surface__mesh__simplification_1_1Bounded__normal__change__filter.html#afa984a31498ede63f04f9fe58f4a182c", null ],
      [ "operator()", "classCGAL_1_1Surface__mesh__simplification_1_1Bounded__normal__change__filter.html#a8b01495720d6ee1bdef96e4e85848c46", null ]
    ] ],
    [ "Bounded_normal_change_placement", "classCGAL_1_1Surface__mesh__simplification_1_1Bounded__normal__change__placement.html", [
      [ "Bounded_normal_change_placement", "classCGAL_1_1Surface__mesh__simplification_1_1Bounded__normal__change__placement.html#aa0930a43888d0bc99f51391b690c2b5e", null ],
      [ "Bounded_normal_change_placement", "classCGAL_1_1Surface__mesh__simplification_1_1Bounded__normal__change__placement.html#a3407420970b3b521a9f9fca035073c70", null ],
      [ "operator()", "classCGAL_1_1Surface__mesh__simplification_1_1Bounded__normal__change__placement.html#a5588d9ec9321610198e39d9f97af2b13", null ]
    ] ],
    [ "Constrained_placement", "classCGAL_1_1Surface__mesh__simplification_1_1Constrained__placement.html", [
      [ "Constrained_placement", "classCGAL_1_1Surface__mesh__simplification_1_1Constrained__placement.html#a4e6c8181c10222cc1534c4021c73afe1", null ]
    ] ],
    [ "Count_ratio_stop_predicate", "classCGAL_1_1Surface__mesh__simplification_1_1Count__ratio__stop__predicate.html", [
      [ "Count_ratio_stop_predicate", "classCGAL_1_1Surface__mesh__simplification_1_1Count__ratio__stop__predicate.html#ae7c4b33fe17aae30981353449882d73b", null ],
      [ "operator()", "classCGAL_1_1Surface__mesh__simplification_1_1Count__ratio__stop__predicate.html#a3c746ca87d0525ec54e83550b2370949", null ]
    ] ],
    [ "Count_stop_predicate", "classCGAL_1_1Surface__mesh__simplification_1_1Count__stop__predicate.html", [
      [ "Count_stop_predicate", "classCGAL_1_1Surface__mesh__simplification_1_1Count__stop__predicate.html#a3f6f8f8d3e19ed6429a4034b34f5a4d0", null ],
      [ "operator()", "classCGAL_1_1Surface__mesh__simplification_1_1Count__stop__predicate.html#ad4304de44e78302e78ab9c4b25252f33", null ]
    ] ],
    [ "Edge_length_cost", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__length__cost.html", [
      [ "Edge_length_cost", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__length__cost.html#a5dfab61ec6db0223d011c68fe70d2dad", null ],
      [ "operator()", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__length__cost.html#af5915cbbb2e9e1f15ae5f99daf4787c8", null ]
    ] ],
    [ "Edge_length_stop_predicate", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__length__stop__predicate.html", [
      [ "Edge_length_stop_predicate", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__length__stop__predicate.html#ada06f5ddd3b86d715a6820eebb09c02a", null ],
      [ "operator()", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__length__stop__predicate.html#a5e33c02017e71abb7a521863aaa10721", null ]
    ] ],
    [ "Edge_profile", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html", [
      [ "edge_descriptor", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#ac53009c4bdf3b085da3ab4df34c4fe84", null ],
      [ "edges_size_type", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#afc622e5fea3e9271a9e8f2a4dc36a678", null ],
      [ "FT", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#ad0c5db091a74548d651ac32abc2abcbc", null ],
      [ "Geom_traits", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#ad4194f46a47b26c789c9539875471718", null ],
      [ "halfedge_descriptor", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#aa8df05005d1c7ceba1bfb2c9e91991be", null ],
      [ "Point", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a1428e94a5c6d4906b6d24d987ddf2e19", null ],
      [ "Triangle_mesh", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a119f2e721d71532ab525ba919444f027", null ],
      [ "vertex_descriptor", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#ad192d90a05ef48861956fa8f2fa8fd6f", null ],
      [ "Vertex_point_map", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#ae3c96d83f9e89bc8630c416ed7c45376", null ],
      [ "border_edges", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a092d4e360d557f3dc4a43c9728131fa2", null ],
      [ "geom_traits", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a5bbab9c7967127dd0a1d254d7738eb56", null ],
      [ "left_face_exists", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a113070ed81cbade3ac0083973302436a", null ],
      [ "link", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a1aceb9a31fe08c91c72f14d7ca8981d7", null ],
      [ "p0", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#ab785a29f857e49df2c603754e6bfa927", null ],
      [ "p1", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#aeb9652afb34889604eb28f73c0f2d4d6", null ],
      [ "right_face_exists", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a30f659a5eaecdd3dd4593f95b7a39495", null ],
      [ "surface_mesh", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a7c10c291981cccf38adbad2503cd15f2", null ],
      [ "v0", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#ab5018d64678847a11b2a1ae3f060f20f", null ],
      [ "v0_v1", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a63fd769d1492330df0585a805e01291a", null ],
      [ "v0_vR", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a4dedf65f8be303336bb92ae0401b651f", null ],
      [ "v1", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a1d52cf119efcac309ee492642fe95851", null ],
      [ "v1_v0", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a8a157ccdc4e88eed183aa9aef4f64da4", null ],
      [ "v1_vL", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a9b4b3181813309ea6c3fe2f9969c4e38", null ],
      [ "vertex_point_map", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a4c9f88feb0185dee205637ebf4ffe457", null ],
      [ "vL", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a4faa5384a0c1ddff1b438a14b15779b5", null ],
      [ "vL_v0", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a647d2d477538ac0ebdc0271f1c64ff25", null ],
      [ "vR", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a510ab6920d65d2d0d806c62d4fe973ae", null ],
      [ "vR_v1", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html#a5d2e5f9251a7a1ebfb89a8aea83685bf", null ]
    ] ],
    [ "GarlandHeckbert_plane_policies", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__plane__policies.html", [
      [ "Get_cost", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__plane__policies.html#afe2ef4b48cf6b530141bdc76d71786f7", null ],
      [ "Get_placement", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__plane__policies.html#a5713e93f59cfcb4a7adc34fe397dab7a", null ],
      [ "GarlandHeckbert_plane_policies", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__plane__policies.html#aebc51f941231c316b73f352f44e5798d", null ],
      [ "get_cost", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__plane__policies.html#abd8fb62a7a4ea9fa8c6cb1816f242312", null ],
      [ "get_placement", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__plane__policies.html#a3474c5eb46a792a957fcbe0f1af55abd", null ]
    ] ],
    [ "GarlandHeckbert_policies", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__policies.html", [
      [ "Get_cost", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__policies.html#a34846d79ca2a827ca86063a70bb94aac", null ],
      [ "Get_placement", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__policies.html#a4205f1bb9f683ecdb719ca7cf06e6a9c", null ],
      [ "GarlandHeckbert_policies", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__policies.html#ae797d0159f034567228d3d88328bd92d", null ],
      [ "get_cost", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__policies.html#ad56b66ac448aec2f2a3ce0edad8f700b", null ],
      [ "get_placement", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__policies.html#abbac3f52bbc4b8b773ca0fbb6f184773", null ]
    ] ],
    [ "GarlandHeckbert_probabilistic_plane_policies", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__probabilistic__plane__policies.html", [
      [ "Get_cost", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__probabilistic__plane__policies.html#ac7f8d6e4ff01f482ef7b4a1b1b6db76a", null ],
      [ "Get_placement", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__probabilistic__plane__policies.html#abce4d53295939da78c2cf214f71d82df", null ],
      [ "GarlandHeckbert_probabilistic_plane_policies", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__probabilistic__plane__policies.html#a0fa695a7d71124a856752af997aa6511", null ],
      [ "get_cost", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__probabilistic__plane__policies.html#aafa084fdeffa85beaa1650c5b9705fd9", null ],
      [ "get_placement", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__probabilistic__plane__policies.html#a2ae49f900d563de658dbb8722c9f3b92", null ]
    ] ],
    [ "GarlandHeckbert_probabilistic_triangle_policies", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__probabilistic__triangle__policies.html", [
      [ "Get_cost", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__probabilistic__triangle__policies.html#a79d6100892903149f54bcaf139357004", null ],
      [ "Get_placement", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__probabilistic__triangle__policies.html#a572dbe61f4224c1d0bb388d34c17a9f7", null ],
      [ "GarlandHeckbert_probabilistic_triangle_policies", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__probabilistic__triangle__policies.html#ab3b691ca56fdd70ea3f5fa7568ea119f", null ],
      [ "get_cost", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__probabilistic__triangle__policies.html#a1aafc15cf27f9147b62876b62ff4b2a0", null ],
      [ "get_placement", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__probabilistic__triangle__policies.html#af94eb393f8c4b33d464d8629f13f186c", null ]
    ] ],
    [ "GarlandHeckbert_triangle_policies", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__triangle__policies.html", [
      [ "Get_cost", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__triangle__policies.html#ae2b6e4346032facf7c11aaa31072e9b5", null ],
      [ "Get_placement", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__triangle__policies.html#aea76ed8fb64753cd37429621af2e0580", null ],
      [ "GarlandHeckbert_triangle_policies", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__triangle__policies.html#ad35ce9d4361264eef13601894c20b30b", null ],
      [ "get_cost", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__triangle__policies.html#ada6bf5308b347463d3d3f8ab878ed58f", null ],
      [ "get_placement", "classCGAL_1_1Surface__mesh__simplification_1_1GarlandHeckbert__triangle__policies.html#aa4f524c0a1c5671068e18c3c60c3c661", null ]
    ] ],
    [ "LindstromTurk_cost", "classCGAL_1_1Surface__mesh__simplification_1_1LindstromTurk__cost.html", [
      [ "LindstromTurk_cost", "classCGAL_1_1Surface__mesh__simplification_1_1LindstromTurk__cost.html#a7373afdc3960cdd92d26c56b961b9bb2", null ],
      [ "operator()", "classCGAL_1_1Surface__mesh__simplification_1_1LindstromTurk__cost.html#a4f1f44dd6e87334795826618e332e9bb", null ]
    ] ],
    [ "LindstromTurk_placement", "classCGAL_1_1Surface__mesh__simplification_1_1LindstromTurk__placement.html", [
      [ "LindstromTurk_placement", "classCGAL_1_1Surface__mesh__simplification_1_1LindstromTurk__placement.html#a2b44349a0543a6c94f211b50bbba2725", null ],
      [ "operator()", "classCGAL_1_1Surface__mesh__simplification_1_1LindstromTurk__placement.html#a4905c72cecc8ae67198f61b1bab26650", null ]
    ] ],
    [ "Midpoint_placement", "classCGAL_1_1Surface__mesh__simplification_1_1Midpoint__placement.html", [
      [ "Midpoint_placement", "classCGAL_1_1Surface__mesh__simplification_1_1Midpoint__placement.html#ae8420ca8ac91298c9e36cefa9781d6a2", null ],
      [ "operator()", "classCGAL_1_1Surface__mesh__simplification_1_1Midpoint__placement.html#a2d44e952ea69f039727b47ab3e7aa1c5", null ]
    ] ],
    [ "Polyhedral_envelope_filter", "classCGAL_1_1Surface__mesh__simplification_1_1Polyhedral__envelope__filter.html", [
      [ "FT", "classCGAL_1_1Surface__mesh__simplification_1_1Polyhedral__envelope__filter.html#a99e59acb6fab15420d04f9bf07121197", null ],
      [ "Polyhedral_envelope_filter", "classCGAL_1_1Surface__mesh__simplification_1_1Polyhedral__envelope__filter.html#a6b56416caa9952dd87388bd086ecee34", null ],
      [ "Polyhedral_envelope_filter", "classCGAL_1_1Surface__mesh__simplification_1_1Polyhedral__envelope__filter.html#a6d49a1bcbd2b263aef9f05dd40ddde8a", null ],
      [ "operator()", "classCGAL_1_1Surface__mesh__simplification_1_1Polyhedral__envelope__filter.html#a654e09685a569d356b7444ac356fd948", null ]
    ] ],
    [ "edge_collapse", "group__PkgSurfaceMeshSimplificationRef.html#ga9efb9a78f5138d74ed6e456e6190a99a", null ]
];
